# Developer Guide
Resources for developers working with SAP LeanIX.
As a developer, you can retrieve data programmatically and build custom integrations with SAP LeanIX. Explore the topics in this section to find the information you need:
  * [Basics](https://help.sap.com/docs/leanix/ea/basics?locale=en-US&state=PRODUCTION&version=CLOUD "Explore the essentials to start building your integrations."): Learn how to choose a technology for your integration and authenticate to SAP LeanIX services.
  * [Guides and Tutorials](https://help.sap.com/docs/leanix/ea/overview?locale=en-US&state=PRODUCTION&version=CLOUD): Explore practical examples of using our technologies.
  * [SAP LeanIX APIs](https://help.sap.com/docs/leanix/ea/sap-leanix-apis?locale=en-US&state=PRODUCTION&version=CLOUD "Explore SAP LeanIX APIs and learn when to use each API."): Get an overview of our APIs and learn when to use each.
  * [Reporting Framework and CLI](https://help.sap.com/docs/leanix/ea/reporting-framework-and-cli?locale=en-US&state=PRODUCTION&version=CLOUD "Build custom reports using the LeanIX Reporting Framework and CLI."): Build custom reports tailored to your needs.
  * [MCP Server](https://help.sap.com/docs/leanix/ea/mcp-server?locale=en-US&state=PRODUCTION&version=CLOUD "Connect external AI applications to SAP LeanIX using the Model Context Protocol \(MCP\) server to securely access enterprise architecture data."): Learn how the MCP server for SAP LeanIX works and how to connect to it.


For additional information, refer to the following resources:
  * [Getting Started](https://help.sap.com/docs/leanix/ea/getting-started?locale=en-US&state=PRODUCTION&version=CLOUD "Introductory guide to begin your journey with SAP LeanIX."): Get an overview of SAP LeanIX and explore its key concepts and features.
  * [SAP LeanIX Community![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fcommunity.leanix.net%2F "https://community.leanix.net/"): Connect with our community to share experiences, exchange ideas, and seek advice. Join the [SAP LeanIX Developers![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fcommunity.leanix.net%2Fgroups%2Fleanix-eam-developers-84 "https://community.leanix.net/groups/leanix-eam-developers-84") group to discuss technical topics with developers and industry experts.
